@@ -1,4 +1,4 @@
-# Gufw 15.04.0 - http://gufw.org
+# Gufw 16.04.0 - http://gufw.org
 # Copyright (C) 2008-2015 Marcos Alvarez Costales https://launchpad.net/~costales
 #
 # Gufw is free software; you can redistribute it and/or modify
@@ -255,8 +255,14 @@ class Firewall():
                 continue
         return ''
     
-    def get_net_interfaces(self):
-        return interfaces()
+    def get_net_interfaces(self, exclude_iface=''):
+        all_faces = interfaces()
+        if exclude_iface:
+            try:
+                all_faces.remove(exclude_iface)
+            except:
+                pass
+        return all_faces
     
     
     # STUFF
