@@ -1,5 +1,5 @@
 #!/usr/bin/env python
-# Gufw 15.10.0 - http://gufw.org
+# Gufw 16.04.0 - http://gufw.org
 # Copyright (C) 2008-2015 Marcos Alvarez Costales https://launchpad.net/~costales
 #
 # Gufw is free software; you can redistribute it and/or modify
@@ -335,7 +335,10 @@ class Backend():
         
         return new_line
 
-    def get_log(self): # OK
+    def get_log(self):
+        if not os.path.isfile(self.GUFW_LOG):
+            return ''
+        
         cmd = self._run_cmd(['cat', self.GUFW_LOG])
         if not cmd:
             return ''
