@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Gufw 15.04.0 - http://gufw.org
+# Gufw 16.04.0 - http://gufw.org
 # Copyright (C) 2008-2015 Marcos Alvarez Costales https://launchpad.net/~costales
 #
 # Gufw is free software; you can redistribute it and/or modify
@@ -47,7 +47,8 @@ class Add:
     
     def _set_objects_name(self):
         self.win_add = self.builder.get_object('AddRule')
-        self.tabs = self.builder.get_object('addTabs')
+        self.tabs    = self.builder.get_object('addTabs')
+        self.add_btn = self.builder.get_object('btnAddRuleWin')
         
         self.preconfig_policy      = self.builder.get_object('preconfig_policy')
         self.preconfig_direction   = self.builder.get_object('preconfig_direction')
@@ -79,7 +80,7 @@ class Add:
         self.advanced_from_port  = self.builder.get_object('advanced_from_port')
         self.advanced_to_ip      = self.builder.get_object('advanced_to_ip')
         self.advanced_to_port    = self.builder.get_object('advanced_to_port')
-
+    
     def _set_initial_values(self):
         self._set_app_combobox()
         
@@ -185,19 +186,57 @@ class Add:
         self.advanced_to_port.set_text(self.apps.get_app(self.preconfig_app.get_active_text())[1])
         self.tabs.set_current_page(2)
     
+    def _set_advanced_addBtn_control(self, ntab):
+        # Not allow Both Protocol with a range of ports in Simple and Advanced tab
+        if ntab == 2 and (':' in self.advanced_to_port.get_text() or ':' in self.advanced_from_port.get_text()) and not self.advanced_protocol.get_active():
+            self.add_btn.set_sensitive(False)
+            self.add_btn.set_tooltip_text(_("Choose a TCP or UDP Protocol with a range of ports"))
+        else:
+            self.add_btn.set_sensitive(True)
+            self.add_btn.set_tooltip_text('')
+    
+    def _set_simple_addBtn_control(self, ntab):
+        # Not allow Both Protocol with a range of ports in Simple and Advanced tab
+        if ntab == 1 and ':' in self.simple_port.get_text() and not self.simple_protocol.get_active():
+            self.add_btn.set_sensitive(False)
+            self.add_btn.set_tooltip_text(_("Choose a TCP or UDP Protocol with a range of ports"))
+        else:
+            self.add_btn.set_sensitive(True)
+            self.add_btn.set_tooltip_text('')
+    
+    def on_addTabs_switch_page(self, widget, data=None, change_to_ntab=None):
+        if change_to_ntab == 1:
+            self._set_simple_addBtn_control(change_to_ntab)
+        elif change_to_ntab == 2:
+            self._set_advanced_addBtn_control(change_to_ntab)
+        else:
+            self.add_btn.set_sensitive(True)
+            self.add_btn.set_tooltip_text('')
+    
+    def on_simple_protocol_changed(self, widget, data=None):
+        self._set_simple_addBtn_control(self.tabs.get_current_page())
+    
+    def on_simple_port_changed(self, widget, data=None):
+        self._set_simple_addBtn_control(self.tabs.get_current_page())
+    
+    def on_advanced_protocol_changed(self, widget, data=None):
+        self._set_advanced_addBtn_control(self.tabs.get_current_page())
+    
     def on_advanced_from_port_changed(self, widget, data=None):
-        if ('/' in self.advanced_from_port.get_text() or
-            '/' in self.advanced_from_port.get_text()):
+        if '/' in self.advanced_from_port.get_text():
             self._set_from_port_sensitive(False)
         else:
             self._set_from_port_sensitive(True)
+        
+        self._set_advanced_addBtn_control(self.tabs.get_current_page())
     
     def on_advanced_to_port_changed(self, widget, data=None):
-        if ('/' in self.advanced_to_port.get_text() or
-            '/' in self.advanced_to_port.get_text()):
+        if '/' in self.advanced_to_port.get_text():
             self._set_to_port_sensitive(False)
         else:
             self._set_to_port_sensitive(True)
+        
+        self._set_advanced_addBtn_control(self.tabs.get_current_page())
     
     def _set_from_port_sensitive(self, value=True):
         self.advanced_protocol.set_sensitive(value)
@@ -311,6 +350,14 @@ class Add:
         else:
             self.advanced_routed.set_sensitive(False)
             self.advanced_routed.set_tooltip_text(_("You need to set an Interface for forwarding to this another interface"))
+        
+        # Not allow same iface when is routed
+        if self.gufw.fw.get_policy('routed') != 'disabled':
+            self.advanced_routed.remove_all()
+            self.advanced_routed.append_text(_("Not Forward"))
+            for ifaceName in self.gufw.fw.get_net_interfaces(self.advanced_iface.get_active_text()):
+                self.advanced_routed.append_text(ifaceName)
+            self.advanced_routed.set_active(0)
     
     def on_preconfig_app_changed(self, widget, data=None):
         if self.preconfig_app.get_active_text() != None:
