@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Gufw 15.04.0 - http://gufw.org
+# Gufw 16.04.0 - http://gufw.org
 # Copyright (C) 2008-2015 Marcos Alvarez Costales https://launchpad.net/~costales
 #
 # Gufw is free software; you can redistribute it and/or modify
@@ -344,6 +344,7 @@ class Gufw:
     
     def on_menu_import_activate(self, widget, data=None):
         import_profile = self._file_dialog('open', _("Import Profile"))
+        
         profile = os.path.basename(import_profile) #Filename
         profile = os.path.splitext(profile)[0] # Ext
         
@@ -351,6 +352,10 @@ class Gufw:
             self.set_statusbar_msg(_("Import cancelled"))
             return
         
+        if oct(os.stat(import_profile).st_mode & 0777) != oct(0600):
+            self.show_dialog(self.winMain, _("Error"), _("Filename has wrong permissions (not 600). Trust only on your exported profiles"))
+            return
+        
         if not re.match('^[A-Za-z0-9_-]*$', profile):
             self.show_dialog(self.winMain, _("Error"), _("Filename has not valid characters. Rename the file\nto only letters, numbers, dashes and underscores"))
             return
